﻿using HotelContracts.BindingModels;
using HotelContracts.SearchModels;
using HotelContracts.StoragesContracts;
using HotelContracts.ViewModels;
using HotelDatabaseImplement.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HotelDatabaseImplement.Implements
{
    public class PostStorage : IPostStorage
    {
        public PostViewModel? Delete(PostBindingModel model)
        {
            using var context = new HotelDatabase();
            var element = context.Posts.FirstOrDefault(x => x.Id == model.Id);
            if (element != null)
            {
                context.Posts.Remove(element);
                context.SaveChanges();
                return element.GetViewModel;
            }
            return null;
        }

        public PostViewModel? GetElement(PostSearchModel model)
        {
            if (string.IsNullOrEmpty(model.PostName) && !model.Id.HasValue)
            {
                return null;
            }
            using var context = new HotelDatabase();
            return context.Posts.FirstOrDefault(x => (!string.IsNullOrEmpty(model.PostName)) && x.PostName == model.PostName || model.Id.HasValue && x.Id == model.Id)?.GetViewModel;
        }

        public List<PostViewModel> GetFilteredList(PostSearchModel model)
        {
            if (string.IsNullOrEmpty(model.PostName))
            {
                return new();
            }
            using var context = new HotelDatabase();
            return context.Posts.Where(x => x.PostName.Contains(model.PostName)).Select(x => x.GetViewModel).ToList();
        }

        public List<PostViewModel> GetFullList()
        {
            using var context = new HotelDatabase();
            return context.Posts.Select(x => x.GetViewModel).ToList();
        }

        public PostViewModel? Insert(PostBindingModel model)
        {
            var newPost = Post.Create(model);
            if (newPost == null)
            {
                return null;
            }
            using var context = new HotelDatabase();
            context.Posts.Add(newPost);
            context.SaveChanges();
            return newPost.GetViewModel;
        }

        public PostViewModel? Update(PostBindingModel model)
        {
            using var context = new HotelDatabase();
            var component = context.Posts.FirstOrDefault(x => x.Id == model.Id);
            if (component == null)
            {
                return null;
            }
            component.Update(model);
            context.SaveChanges();
            return component.GetViewModel;
        }
    }
}
